@@ -396,3 +396,7 @@ class HasEventHooks(object):
 
     def addEventHook(self, topic: str, handler):
         self.eventHooks[topic] = handler
+
+    def deleteEventHook(self, topic: str):
+        if topic in self.eventHooks:
+            del self.eventHooks[topic]
